#[non_exhaustive]pub struct PrewarmPoolStatus { /* private fields */ }Expand description
Current resource state of a bounded prewarmed database queue.
Implementations
Sourceimpl PrewarmPoolStatus
impl PrewarmPoolStatus
pub const fn capacity(&self) -> usize
pub const fn ready(&self) -> usize
pub const fn leased(&self) -> usize
pub const fn creating(&self) -> usize
pub const fn deleting(&self) -> usize
pub const fn is_closed(&self) -> bool
Sourcepub const fn occupied_slots(&self) -> usize
pub const fn occupied_slots(&self) -> usize
Returns the number of capacity slots currently represented by ready, leased, creating, or deleting work.